import * as i0 from '@angular/core';
import { inject, ElementRef, NgZone, signal, EventEmitter, Directive, ViewChild, Input, Output, Component } from '@angular/core';
import { mergeDeep, naturalFieldComparator, buildChart, buildSingleSerieChart } from '@oneteme/jquery-core';
import ApexCharts from 'apexcharts';
import { asapScheduler } from 'rxjs';
import * as i1 from '@angular/common';
import { CommonModule } from '@angular/common';

const ICONS = {
    previous: `<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 -960 960 960" style="width: 15px; height: 15px">
  <path d="M400-80 0-480l400-400 71 71-329 329 329 329-71 71Z"/>
  </svg>`,
    next: `<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 -960 960 960" style="width: 15px; height: 15px"><path d="m321-80-71-71 329-329-329-329 71-71 400 400L321-80Z"/></svg>`,
    pivot: `<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 -960 960 960" style="width: 15px; height: 15px"><path d="M400-640v-200h360q33 0 56.5 23.5T840-760v120H400ZM200-120q-33 0-56.5-23.5T120-200v-360h200v440H200Zm-80-520v-120q0-33 23.5-56.5T200-840h120v200H120ZM520-80 360-240l160-160 56 56-62 64h86q33 0 56.5-23.5T680-360v-88l-64 64-56-56 160-160 160 160-56 56-64-64v88q0 66-47 113t-113 47h-86l62 64-56 56Z"/></svg>`,
};

function customIcons(event, canPivot) {
    var customIcons = [{
            icon: ICONS.previous,
            title: 'Graphique précédent',
            class: 'custom-icon',
            click: function (chart, options, e) {
                event("previous");
            }
        },
        {
            icon: ICONS.next,
            title: 'Graphique suivant',
            class: 'custom-icon',
            click: function (chart, options, e) {
                event("next");
            }
        }];
    if (canPivot) {
        customIcons.push({
            icon: ICONS.pivot,
            title: 'Pivot',
            class: 'custom-icon',
            click: function (chart, options, e) {
                event("pivot");
            }
        });
    }
    return customIcons;
}
function getType(commonChart) {
    if (commonChart.series.length && commonChart.series[0].data.length) {
        if (commonChart.continue) {
            var x = commonChart.series[0].data[0].x;
            return x instanceof Date ? 'datetime' : typeof x == 'number' ? 'numeric' : 'category';
        }
        else {
            var categ = commonChart.categories[0];
            return categ instanceof Date ? 'datetime' : typeof categ == 'number' ? 'numeric' : 'category';
        }
    }
    return 'datetime';
}

class BarChartDirective {
    constructor() {
        this.el = inject(ElementRef);
        this.ngZone = inject(NgZone);
        this.chartInstance = signal(null);
        this._chartConfig = { showToolbar: false };
        this._options = {
            chart: {
                type: 'bar'
            },
            series: [{
                    data: []
                }]
        };
        this.canPivot = true;
        this.isLoading = false;
        this.customEvent = new EventEmitter();
    }
    ngOnDestroy() {
        this.destroy();
    }
    ngOnChanges(changes) {
        this.ngZone.runOutsideAngular(() => {
            asapScheduler.schedule(() => this.hydrate(changes));
        });
    }
    hydrate(changes) {
        const shouldUpdateSeries = Object.keys(changes).filter((c) => c !== "data" && c !== "isLoading").length === 0;
        if (shouldUpdateSeries) {
            this.updateLoading();
            this.updateData();
            this.updateOptions(this._options, true, true, false);
            return;
        }
        this.createElement();
    }
    createElement() {
        this.updateConfig();
        this.updateLoading();
        this.updateData();
        if (this.chartInstance() != null) {
            this.updateOptions(this._options, true, true, false);
        }
        else {
            this.destroy();
            const chartInstance = this.ngZone.runOutsideAngular(() => new ApexCharts(this.el.nativeElement, this._options));
            this.chartInstance.set(chartInstance);
            this.render();
        }
    }
    render() {
        return this.ngZone.runOutsideAngular(() => this.chartInstance()?.render());
    }
    destroy() {
        this.chartInstance()?.destroy();
        this.chartInstance.set(null);
    }
    updateConfig() {
        let that = this;
        this._chartConfig = this.config;
        mergeDeep(this._options, {
            chart: {
                height: this._chartConfig.height ?? '100%',
                width: this._chartConfig.width ?? '100%',
                stacked: this._chartConfig.stacked,
                toolbar: {
                    show: this._chartConfig.showToolbar ?? false,
                    tools: {
                        download: false,
                        selection: false,
                        zoom: false,
                        zoomin: false,
                        zoomout: false,
                        pan: false,
                        reset: false,
                        customIcons: customIcons((arg) => { that.ngZone.run(() => that.customEvent.emit(arg)); }, this.canPivot)
                    }
                },
                events: {
                    mouseMove: function (e, c, config) {
                        var toolbar = that.el.nativeElement.querySelector('.apexcharts-toolbar');
                        toolbar ? toolbar.style.visibility = "visible" : null;
                    },
                    mouseLeave: function (e, c, config) {
                        var toolbar = that.el.nativeElement.querySelector('.apexcharts-toolbar');
                        toolbar ? toolbar.style.visibility = "hidden" : null;
                    }
                }
            },
            title: {
                text: this._chartConfig.title
            },
            subtitle: {
                text: this._chartConfig.subtitle
            },
            xaxis: {
                title: {
                    text: this._chartConfig.xtitle
                }
            },
            yaxis: {
                title: {
                    text: this._chartConfig.ytitle
                }
            }
        }, this.type == 'bar' ? {
            plotOptions: {
                bar: {
                    horizontal: true
                }
            }
        } : {}, this._chartConfig.options);
    }
    updateData() {
        var data = [...this.data];
        if (this.type == 'funnel') {
            data = data.sort(naturalFieldComparator('asc', this._chartConfig.series[0].data.y));
        }
        else if (this.type == 'pyramid') {
            data = data.sort(naturalFieldComparator('desc', this._chartConfig.series[0].data.y));
        }
        var commonChart = buildChart(data, { ...this._chartConfig, pivot: !this.canPivot ? false : this._chartConfig.pivot });
        mergeDeep(this._options, { series: commonChart.series.length ? commonChart.series.map(s => ({ data: s.data, name: s.name, color: s.color, group: s.stack })) : [{ data: [] }], xaxis: { type: getType(commonChart), categories: commonChart.categories || [] } });
    }
    updateLoading() {
        mergeDeep(this._options, {
            noData: {
                text: this.isLoading ? 'Loading...' : 'Aucune donnée'
            }
        });
    }
    updateType() {
        mergeDeep(this._options, { chart: { type: this.type } });
    }
    updateOptions(options, redrawPaths, animate, updateSyncedCharts) {
        return this.ngZone.runOutsideAngular(() => this.chartInstance()?.updateOptions(options, redrawPaths, animate, updateSyncedCharts));
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: BarChartDirective, deps: [], target: i0.ɵɵFactoryTarget.Directive }); }
    static { this.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "16.2.12", type: BarChartDirective, isStandalone: true, selector: "[bar-chart]", inputs: { type: "type", config: "config", data: "data", canPivot: "canPivot", isLoading: "isLoading" }, outputs: { customEvent: "customEvent" }, viewQueries: [{ propertyName: "chartElement", first: true, predicate: ["chart"], descendants: true, static: true }], usesOnChanges: true, ngImport: i0 }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: BarChartDirective, decorators: [{
            type: Directive,
            args: [{
                    standalone: true,
                    selector: '[bar-chart]'
                }]
        }], propDecorators: { chartElement: [{
                type: ViewChild,
                args: ["chart", { static: true }]
            }], type: [{
                type: Input,
                args: [{ required: true }]
            }], config: [{
                type: Input,
                args: [{ required: true }]
            }], data: [{
                type: Input,
                args: [{ required: true }]
            }], canPivot: [{
                type: Input
            }], isLoading: [{
                type: Input
            }], customEvent: [{
                type: Output
            }] } });

class LineChartDirective {
    constructor() {
        this.el = inject(ElementRef);
        this.ngZone = inject(NgZone);
        this.chartInstance = signal(null);
        this._chartConfig = { showToolbar: false };
        this._options = {
            chart: {
                type: 'line'
            },
            series: [],
            noData: {
                text: 'Aucune donnée'
            }
        };
        this.isLoading = false;
        this.customEvent = new EventEmitter();
    }
    ngOnChanges(changes) {
        this.ngZone.runOutsideAngular(() => {
            asapScheduler.schedule(() => this.hydrate(changes));
        });
    }
    ngOnDestroy() {
        this.destroy();
    }
    hydrate(changes) {
        const shouldUpdateSeries = Object.keys(changes).filter((c) => c !== "data" && c !== "isLoading").length === 0;
        if (shouldUpdateSeries) {
            this.updateLoading();
            this.updateData();
            this.updateOptions(this._options, true, true, false);
            return;
        }
        this.createElement();
    }
    createElement() {
        this.updateConfig();
        this.updateType();
        this.updateLoading();
        this.updateData();
        if (this.chartInstance() != null) {
            this.updateOptions(this._options, true, true, false);
        }
        else {
            this.destroy();
            const chartInstance = this.ngZone.runOutsideAngular(() => new ApexCharts(this.el.nativeElement, this._options));
            this.chartInstance.set(chartInstance);
            this.render();
        }
    }
    render() {
        return this.ngZone.runOutsideAngular(() => this.chartInstance()?.render());
    }
    destroy() {
        this.chartInstance()?.destroy();
        this.chartInstance.set(null);
    }
    updateConfig() {
        let that = this;
        this._chartConfig = this.config;
        mergeDeep(this._options, {
            chart: {
                height: this._chartConfig.height ?? '100%',
                width: this._chartConfig.width ?? '100%',
                stacked: this._chartConfig.stacked,
                toolbar: {
                    show: this._chartConfig.showToolbar ?? false,
                    tools: {
                        download: false,
                        selection: false,
                        zoom: false,
                        zoomin: false,
                        zoomout: false,
                        pan: false,
                        reset: false,
                        customIcons: customIcons(arg => { that.ngZone.run(() => that.customEvent.emit(arg)); }, true)
                    }
                },
                events: {
                    mouseMove: function (e, c, config) {
                        var toolbar = that.el.nativeElement.querySelector('.apexcharts-toolbar');
                        toolbar ? toolbar.style.visibility = "visible" : null;
                    },
                    mouseLeave: function (e, c, config) {
                        var toolbar = that.el.nativeElement.querySelector('.apexcharts-toolbar');
                        toolbar ? toolbar.style.visibility = "hidden" : null;
                    }
                }
            },
            title: {
                text: this._chartConfig.title
            },
            subtitle: {
                text: this._chartConfig.subtitle
            },
            xaxis: {
                title: {
                    text: this._chartConfig.xtitle
                }
            },
            yaxis: {
                title: {
                    text: this._chartConfig.ytitle
                }
            }
        }, this._chartConfig.options);
    }
    updateLoading() {
        mergeDeep(this._options, {
            noData: {
                text: this.isLoading ? 'Loading...' : 'Aucune donnée'
            }
        });
    }
    updateType() {
        mergeDeep(this._options, { chart: { type: this.type } });
    }
    updateData() {
        var commonChart = buildChart(this.data, { ...this._chartConfig, continue: true }, null);
        mergeDeep(this._options, { series: commonChart.series, xaxis: { type: getType(commonChart) } });
    }
    updateOptions(options, redrawPaths, animate, updateSyncedCharts) {
        return this.ngZone.runOutsideAngular(() => this.chartInstance()?.updateOptions(options, redrawPaths, animate, updateSyncedCharts));
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: LineChartDirective, deps: [], target: i0.ɵɵFactoryTarget.Directive }); }
    static { this.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "16.2.12", type: LineChartDirective, isStandalone: true, selector: "[line-chart]", inputs: { type: "type", config: "config", data: "data", isLoading: "isLoading" }, outputs: { customEvent: "customEvent" }, usesOnChanges: true, ngImport: i0 }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: LineChartDirective, decorators: [{
            type: Directive,
            args: [{
                    standalone: true,
                    selector: '[line-chart]'
                }]
        }], propDecorators: { type: [{
                type: Input,
                args: [{ required: true }]
            }], config: [{
                type: Input,
                args: [{ required: true }]
            }], data: [{
                type: Input,
                args: [{ required: true }]
            }], isLoading: [{
                type: Input
            }], customEvent: [{
                type: Output
            }] } });

class PieChartDirective {
    constructor() {
        this.el = inject(ElementRef);
        this.ngZone = inject(NgZone);
        this.chartInstance = signal(null);
        this.typeMapping = {
            'pie': 'pie',
            'donut': 'donut',
            'radial': 'radialBar',
            'polar': 'polarArea',
            'radar': 'radar'
        };
        this._chartConfig = { showToolbar: false };
        this._options = {
            chart: {
                type: 'pie'
            },
            series: [],
            noData: {
                text: 'Aucune donnée'
            }
        };
        this.isLoading = false;
        this.customEvent = new EventEmitter();
    }
    ngOnDestroy() {
        this.destroy();
    }
    ngOnChanges(changes) {
        this.ngZone.runOutsideAngular(() => {
            asapScheduler.schedule(() => this.hydrate(changes));
        });
    }
    hydrate(changes) {
        const shouldUpdateSeries = Object.keys(changes).filter((c) => c !== "data" && c !== "isLoading").length === 0;
        if (shouldUpdateSeries) {
            this.updateLoading();
            this.updateData();
            this.updateOptions(this._options, true, true, false);
            return;
        }
        this.createElement();
    }
    createElement() {
        this.updateConfig();
        this.updateType();
        this.updateLoading();
        this.updateData();
        if (this.chartInstance() != null) {
            this.updateOptions(this._options, true, true, false);
        }
        else {
            this.destroy();
            const chartInstance = this.ngZone.runOutsideAngular(() => new ApexCharts(this.el.nativeElement, this._options));
            this.chartInstance.set(chartInstance);
            this.render();
        }
    }
    render() {
        return this.ngZone.runOutsideAngular(() => this.chartInstance()?.render());
    }
    destroy() {
        this.chartInstance()?.destroy();
        this.chartInstance.set(null);
    }
    updateConfig() {
        let that = this;
        this._chartConfig = this.config;
        mergeDeep(this._options, {
            chart: {
                height: this._chartConfig.height ?? '100%',
                width: this._chartConfig.width ?? '100%',
                toolbar: {
                    show: this._chartConfig.showToolbar ?? false,
                    tools: {
                        download: false,
                        selection: false,
                        zoom: false,
                        zoomin: false,
                        zoomout: false,
                        pan: false,
                        reset: false,
                        customIcons: customIcons(arg => { that.ngZone.run(() => that.customEvent.emit(arg)); }, true)
                    }
                },
                events: {
                    mouseMove: function (e, c, config) {
                        var toolbar = that.el.nativeElement.querySelector('.apexcharts-toolbar');
                        toolbar ? toolbar.style.visibility = "visible" : null;
                    },
                    mouseLeave: function (e, c, config) {
                        var toolbar = that.el.nativeElement.querySelector('.apexcharts-toolbar');
                        toolbar ? toolbar.style.visibility = "hidden" : null;
                    }
                }
            },
            title: {
                text: this._chartConfig.title
            },
            subtitle: {
                text: this._chartConfig.subtitle
            },
            xaxis: {
                title: {
                    text: this._chartConfig.xtitle
                }
            },
            yaxis: {
                title: {
                    text: this._chartConfig.ytitle
                }
            },
        }, this._chartConfig.options);
    }
    updateLoading() {
        mergeDeep(this._options, {
            noData: {
                text: this.isLoading ? 'Loading...' : 'Aucune donnée'
            }
        });
    }
    updateType() {
        mergeDeep(this._options, { chart: { type: this.typeMapping[this.type] } });
    }
    updateData() {
        var chartConfig = { ...this._chartConfig, continue: false };
        var commonChart = this.data.length != 1 && this.type == 'radar' ? buildChart(this.data, chartConfig, null) : buildSingleSerieChart(this.data, chartConfig, null);
        var colors = commonChart.series.filter(d => d.color).map(d => d.color);
        mergeDeep(this._options, { series: this.data.length != 1 && this.type == 'radar' ? commonChart.series : this.type == 'radar' ? [{ name: 'Series 1', data: commonChart.series.flatMap(s => s.data.filter(d => d != null)) }] : commonChart.series.flatMap(s => s.data.filter(d => d != null)), labels: commonChart.categories || [], colors: colors || [] });
    }
    updateOptions(options, redrawPaths, animate, updateSyncedCharts) {
        return this.ngZone.runOutsideAngular(() => this.chartInstance()?.updateOptions(options, redrawPaths, animate, updateSyncedCharts));
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: PieChartDirective, deps: [], target: i0.ɵɵFactoryTarget.Directive }); }
    static { this.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "16.2.12", type: PieChartDirective, isStandalone: true, selector: "[pie-chart]", inputs: { type: "type", config: "config", data: "data", isLoading: "isLoading" }, outputs: { customEvent: "customEvent" }, usesOnChanges: true, ngImport: i0 }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: PieChartDirective, decorators: [{
            type: Directive,
            args: [{
                    standalone: true,
                    selector: '[pie-chart]'
                }]
        }], propDecorators: { type: [{
                type: Input,
                args: [{ required: true }]
            }], config: [{
                type: Input,
                args: [{ required: true }]
            }], data: [{
                type: Input,
                args: [{ required: true }]
            }], isLoading: [{
                type: Input
            }], customEvent: [{
                type: Output
            }] } });

class TreemapChartDirective {
    constructor() {
        this.el = inject(ElementRef);
        this.ngZone = inject(NgZone);
        this.chartInstance = signal(null);
        this._chartConfig = { showToolbar: false };
        this._options = {
            chart: {
                type: 'treemap'
            },
            series: []
        };
        this.isLoading = false;
        this.customEvent = new EventEmitter();
    }
    ngOnDestroy() {
        this.destroy();
    }
    ngOnChanges(changes) {
        this.ngZone.runOutsideAngular(() => {
            asapScheduler.schedule(() => this.hydrate(changes));
        });
    }
    hydrate(changes) {
        const shouldUpdateSeries = Object.keys(changes).filter((c) => c !== "data" && c !== "isLoading").length === 0;
        if (shouldUpdateSeries) {
            this.updateLoading();
            this.updateData();
            this.updateOptions(this._options, true, true, false);
            return;
        }
        this.createElement();
    }
    createElement() {
        this.updateConfig();
        this.updateType();
        this.updateLoading();
        this.updateData();
        if (this.chartInstance() != null) {
            this.updateOptions(this._options, true, true, false);
        }
        else {
            this.destroy();
            const chartInstance = this.ngZone.runOutsideAngular(() => new ApexCharts(this.el.nativeElement, this._options));
            this.chartInstance.set(chartInstance);
            this.render();
        }
    }
    render() {
        return this.ngZone.runOutsideAngular(() => this.chartInstance()?.render());
    }
    destroy() {
        this.chartInstance()?.destroy();
        this.chartInstance.set(null);
    }
    updateType() {
        mergeDeep(this._options, { chart: { type: this.type } });
    }
    updateConfig() {
        let that = this;
        this._chartConfig = this.config;
        mergeDeep(this._options, {
            chart: {
                height: this._chartConfig.height ?? '100%',
                width: this._chartConfig.width ?? '100%',
                toolbar: {
                    show: this._chartConfig.showToolbar ?? false,
                    tools: {
                        download: false,
                        selection: false,
                        zoom: false,
                        zoomin: false,
                        zoomout: false,
                        pan: false,
                        reset: false,
                        customIcons: customIcons(arg => { that.ngZone.run(() => that.customEvent.emit(arg)); }, true)
                    }
                },
                events: {
                    mouseMove: function (e, c, config) { that.el.nativeElement.querySelector('.apexcharts-toolbar').style.visibility = "visible"; },
                    mouseLeave: function (e, c, config) { that.el.nativeElement.querySelector('.apexcharts-toolbar').style.visibility = "hidden"; }
                }
            },
            title: {
                text: this._chartConfig.title
            },
            subtitle: {
                text: this._chartConfig.subtitle
            },
            xaxis: {
                title: {
                    text: this._chartConfig.xtitle
                }
            },
            yaxis: {
                title: {
                    text: this._chartConfig.ytitle
                }
            }
        }, this._chartConfig.options);
    }
    updateData() {
        var commonChart = buildChart(this.data, { ...this._chartConfig, continue: true }, null);
        mergeDeep(this._options, { series: commonChart.series, xaxis: { type: getType(commonChart) } });
    }
    updateLoading() {
        mergeDeep(this._options, {
            noData: {
                text: this.isLoading ? 'Loading...' : 'Aucune donnée'
            }
        });
    }
    updateOptions(options, redrawPaths, animate, updateSyncedCharts) {
        return this.ngZone.runOutsideAngular(() => this.chartInstance()?.updateOptions(options, redrawPaths, animate, updateSyncedCharts));
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: TreemapChartDirective, deps: [], target: i0.ɵɵFactoryTarget.Directive }); }
    static { this.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "16.2.12", type: TreemapChartDirective, isStandalone: true, selector: "[treemap-chart]", inputs: { type: "type", config: "config", data: "data", isLoading: "isLoading" }, outputs: { customEvent: "customEvent" }, usesOnChanges: true, ngImport: i0 }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: TreemapChartDirective, decorators: [{
            type: Directive,
            args: [{
                    standalone: true,
                    selector: '[treemap-chart]'
                }]
        }], propDecorators: { type: [{
                type: Input,
                args: [{ required: true }]
            }], config: [{
                type: Input,
                args: [{ required: true }]
            }], data: [{
                type: Input,
                args: [{ required: true }]
            }], isLoading: [{
                type: Input
            }], customEvent: [{
                type: Output
            }] } });

class TestChartDirective {
    constructor() {
        this.el = inject(ElementRef);
    }
    ngAfterViewInit() {
        var options = {
            series: [{
                    name: 'Website Blog',
                    type: 'column',
                    data: [440, 505, 414, 671, 227, 413, 201, 352, 752, 320, 257, 160]
                }, {
                    name: 'Social Media',
                    type: 'area',
                    data: [23, 42, 35, 27, 43, 22, 17, 31, 22, 22, 12, 16]
                }],
            chart: {
                height: 350,
                type: 'area',
            },
            dataLabels: {
                enabled: true,
                enabledOnSeries: [1]
            },
            labels: ['01 Jan 2001', '02 Jan 2001', '03 Jan 2001', '04 Jan 2001', '05 Jan 2001', '06 Jan 2001', '07 Jan 2001', '08 Jan 2001', '09 Jan 2001', '10 Jan 2001', '11 Jan 2001', '12 Jan 2001'],
            xaxis: {
                type: 'datetime'
            },
            yaxis: [{
                    title: {
                        text: 'Website Blog',
                    },
                }, {
                    opposite: true,
                    title: {
                        text: 'Social Media'
                    }
                }]
        };
        this._chart = new ApexCharts(this.el.nativeElement, options);
        this._chart.render();
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: TestChartDirective, deps: [], target: i0.ɵɵFactoryTarget.Directive }); }
    static { this.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "16.2.12", type: TestChartDirective, isStandalone: true, selector: "[test-chart]", ngImport: i0 }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: TestChartDirective, decorators: [{
            type: Directive,
            args: [{
                    standalone: true,
                    selector: '[test-chart]'
                }]
        }] });

class RangeChartDirective {
    constructor() {
        this.el = inject(ElementRef);
        this.ngZone = inject(NgZone);
        this.chartInstance = signal(null);
        this._chartConfig = { showToolbar: false };
        this._options = {
            chart: {
                type: 'rangeArea'
            },
            series: []
        };
        this.canPivot = true;
        this.isLoading = false;
        this.customEvent = new EventEmitter();
    }
    ngOnDestroy() {
        this.destroy();
    }
    ngOnChanges(changes) {
        this.ngZone.runOutsideAngular(() => {
            asapScheduler.schedule(() => this.hydrate(changes));
        });
    }
    hydrate(changes) {
        const shouldUpdateSeries = Object.keys(changes).filter((c) => c !== "data" && c !== "isLoading").length === 0;
        if (shouldUpdateSeries) {
            this.updateLoading();
            this.updateData();
            this.updateOptions(this._options, true);
            return;
        }
        this.createElement();
    }
    createElement() {
        this.updateConfig();
        this.updateType();
        this.updateLoading();
        this.updateData();
        if (this.chartInstance() != null) {
            this.updateOptions(this._options, true, true, false);
        }
        else {
            this.destroy();
            const chartInstance = this.ngZone.runOutsideAngular(() => new ApexCharts(this.el.nativeElement, this._options));
            this.chartInstance.set(chartInstance);
            this.render();
        }
    }
    render() {
        return this.ngZone.runOutsideAngular(() => this.chartInstance()?.render());
    }
    destroy() {
        this.chartInstance()?.destroy();
        this.chartInstance.set(null);
    }
    updateType() {
        mergeDeep(this._options, { chart: { type: this.type == 'rangeColumn' ? 'rangeBar' : this.type } });
    }
    updateConfig() {
        let that = this;
        this._chartConfig = this.config;
        mergeDeep(this._options, {
            chart: {
                height: this._chartConfig.height ?? '100%',
                width: this._chartConfig.width ?? '100%',
                toolbar: {
                    show: this._chartConfig.showToolbar ?? false,
                    tools: {
                        download: false,
                        selection: false,
                        zoom: false,
                        zoomin: false,
                        zoomout: false,
                        pan: false,
                        reset: false,
                        customIcons: customIcons(arg => { that.ngZone.run(() => that.customEvent.emit(arg)); }, true)
                    }
                },
                events: {
                    mouseMove: function (e, c, config) { that.el.nativeElement.querySelector('.apexcharts-toolbar').style.visibility = "visible"; },
                    mouseLeave: function (e, c, config) { that.el.nativeElement.querySelector('.apexcharts-toolbar').style.visibility = "hidden"; }
                }
            },
            title: {
                text: this._chartConfig.title
            },
            subtitle: {
                text: this._chartConfig.subtitle
            },
            xaxis: {
                title: {
                    text: this._chartConfig.xtitle
                }
            },
            yaxis: {
                title: {
                    text: this._chartConfig.ytitle
                }
            }
        }, this.type == 'rangeBar' ? {
            plotOptions: {
                bar: {
                    horizontal: true
                }
            }
        } : {}, this._chartConfig.options);
    }
    updateData() {
        var commonChart = buildChart(this.data, { ...this._chartConfig, continue: true, pivot: !this.canPivot ? false : this._chartConfig.pivot }, null);
        mergeDeep(this._options, { series: commonChart.series, xaxis: { type: getType(commonChart) } });
    }
    updateLoading() {
        mergeDeep(this._options, {
            noData: {
                text: this.isLoading ? 'Loading...' : 'Aucune donnée'
            }
        });
    }
    updateOptions(options, redrawPaths, animate, updateSyncedCharts) {
        return this.ngZone.runOutsideAngular(() => this.chartInstance()?.updateOptions(options, redrawPaths, animate, updateSyncedCharts));
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: RangeChartDirective, deps: [], target: i0.ɵɵFactoryTarget.Directive }); }
    static { this.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "16.2.12", type: RangeChartDirective, isStandalone: true, selector: "[range-chart]", inputs: { type: "type", config: "config", data: "data", canPivot: "canPivot", isLoading: "isLoading" }, outputs: { customEvent: "customEvent" }, usesOnChanges: true, ngImport: i0 }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: RangeChartDirective, decorators: [{
            type: Directive,
            args: [{
                    standalone: true,
                    selector: '[range-chart]'
                }]
        }], propDecorators: { type: [{
                type: Input,
                args: [{ required: true }]
            }], config: [{
                type: Input,
                args: [{ required: true }]
            }], data: [{
                type: Input,
                args: [{ required: true }]
            }], canPivot: [{
                type: Input
            }], isLoading: [{
                type: Input
            }], customEvent: [{
                type: Output
            }] } });

class ChartComponent {
    constructor() {
        this._charts = {
            'pie': {
                possibleType: ['pie', 'donut', 'polar', 'radar']
            },
            'donut': {
                possibleType: ['pie', 'donut', 'polar', 'radar']
            },
            'polar': {
                possibleType: ['pie', 'donut', 'polar', 'radar']
            },
            'radar': {
                possibleType: ['pie', 'donut', 'polar', 'radar']
            },
            'line': { possibleType: ['line', 'area'] },
            'area': { possibleType: ['line', 'area'] },
            'bar': { possibleType: ['bar', 'column', 'heatmap', 'treemap'] },
            'column': { possibleType: ['bar', 'column', 'heatmap', 'treemap'] },
            'heatmap': { possibleType: ['bar', 'column', 'heatmap', 'treemap'] },
            'treemap': { possibleType: ['bar', 'column', 'heatmap', 'treemap'] },
            'funnel': { possibleType: ['funnel', 'pyramid'], canPivot: false },
            'pyramid': { possibleType: ['funnel', 'pyramid'], canPivot: false },
            'rangeArea': { possibleType: ['rangeArea', 'rangeBar', 'rangeColumn'], canPivot: false },
            'rangeBar': { possibleType: ['rangeArea', 'rangeBar', 'rangeColumn'] },
            'rangeColumn': { possibleType: ['rangeArea', 'rangeBar', 'rangeColumn'] }
        };
    }
    set value(type) {
        this._type = type;
    }
    change(event) {
        let charts = this._charts[this._type].possibleType;
        let indexOf = charts.indexOf(this._type);
        if (indexOf != -1) {
            if (event == 'previous') {
                this._type = indexOf == 0 ? charts[charts.length - 1] : charts[indexOf - 1];
                return;
            }
            if (event == 'next') {
                this._type = indexOf == charts.length - 1 ? charts[0] : charts[indexOf + 1];
                return;
            }
        }
        if (event == 'pivot') {
            this.config = this.config.pivot ? { ...this.config, pivot: false } : { ...this.config, pivot: true };
            return;
        }
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: ChartComponent, deps: [], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "16.2.12", type: ChartComponent, isStandalone: true, selector: "chart", inputs: { value: ["type", "value"], config: "config", data: "data", isLoading: "isLoading" }, ngImport: i0, template: "<div line-chart *ngIf=\"_type == 'line' || _type == 'area'\" [type]=\"_type\" [config]=\"config\" [data]=\"data\" [isLoading]=\"isLoading\" (customEvent)=\"change($event)\"></div>\n<div pie-chart *ngIf=\"_type == 'donut' || _type == 'polar' || _type == 'radial' || _type == 'radar' || _type == 'pie'\" [type]=\"_type\" [config]=\"config\" [data]=\"data\" [isLoading]=\"isLoading\" (customEvent)=\"change($event)\"></div>\n<div bar-chart *ngIf=\"_type == 'bar' || _type == 'column' || _type == 'funnel' || _type == 'pyramid'\" [type]=\"_type\" [config]=\"config\" [data]=\"data\" [isLoading]=\"isLoading\" (customEvent)=\"change($event)\" [canPivot]=\"_charts[_type].canPivot\"></div>\n<div treemap-chart *ngIf=\"_type == 'treemap' || _type == 'heatmap'\" [type]=\"_type\" [config]=\"config\" [data]=\"data\" [isLoading]=\"isLoading\" (customEvent)=\"change($event)\"></div>\n<div range-chart *ngIf=\"_type == 'rangeArea' || _type == 'rangeBar' || _type == 'rangeColumn'\" [type]=\"_type\" [config]=\"config\" [data]=\"data\" [isLoading]=\"isLoading\" (customEvent)=\"change($event)\" [canPivot]=\"_charts[_type].canPivot\"></div>\n", dependencies: [{ kind: "ngmodule", type: CommonModule }, { kind: "directive", type: i1.NgIf, selector: "[ngIf]", inputs: ["ngIf", "ngIfThen", "ngIfElse"] }, { kind: "directive", type: PieChartDirective, selector: "[pie-chart]", inputs: ["type", "config", "data", "isLoading"], outputs: ["customEvent"] }, { kind: "directive", type: BarChartDirective, selector: "[bar-chart]", inputs: ["type", "config", "data", "canPivot", "isLoading"], outputs: ["customEvent"] }, { kind: "directive", type: LineChartDirective, selector: "[line-chart]", inputs: ["type", "config", "data", "isLoading"], outputs: ["customEvent"] }, { kind: "directive", type: RangeChartDirective, selector: "[range-chart]", inputs: ["type", "config", "data", "canPivot", "isLoading"], outputs: ["customEvent"] }, { kind: "directive", type: TreemapChartDirective, selector: "[treemap-chart]", inputs: ["type", "config", "data", "isLoading"], outputs: ["customEvent"] }] }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: ChartComponent, decorators: [{
            type: Component,
            args: [{ standalone: true, imports: [
                        CommonModule,
                        PieChartDirective,
                        BarChartDirective,
                        LineChartDirective,
                        RangeChartDirective,
                        TreemapChartDirective
                    ], selector: 'chart', template: "<div line-chart *ngIf=\"_type == 'line' || _type == 'area'\" [type]=\"_type\" [config]=\"config\" [data]=\"data\" [isLoading]=\"isLoading\" (customEvent)=\"change($event)\"></div>\n<div pie-chart *ngIf=\"_type == 'donut' || _type == 'polar' || _type == 'radial' || _type == 'radar' || _type == 'pie'\" [type]=\"_type\" [config]=\"config\" [data]=\"data\" [isLoading]=\"isLoading\" (customEvent)=\"change($event)\"></div>\n<div bar-chart *ngIf=\"_type == 'bar' || _type == 'column' || _type == 'funnel' || _type == 'pyramid'\" [type]=\"_type\" [config]=\"config\" [data]=\"data\" [isLoading]=\"isLoading\" (customEvent)=\"change($event)\" [canPivot]=\"_charts[_type].canPivot\"></div>\n<div treemap-chart *ngIf=\"_type == 'treemap' || _type == 'heatmap'\" [type]=\"_type\" [config]=\"config\" [data]=\"data\" [isLoading]=\"isLoading\" (customEvent)=\"change($event)\"></div>\n<div range-chart *ngIf=\"_type == 'rangeArea' || _type == 'rangeBar' || _type == 'rangeColumn'\" [type]=\"_type\" [config]=\"config\" [data]=\"data\" [isLoading]=\"isLoading\" (customEvent)=\"change($event)\" [canPivot]=\"_charts[_type].canPivot\"></div>\n" }]
        }], propDecorators: { value: [{
                type: Input,
                args: [{ alias: "type", required: true }]
            }], config: [{
                type: Input,
                args: [{ required: true }]
            }], data: [{
                type: Input,
                args: [{ required: true }]
            }], isLoading: [{
                type: Input
            }] } });

/*
 * Public API Surface of jquery-apexcharts
 */

/**
 * Generated bundle index. Do not edit.
 */

export { BarChartDirective, ChartComponent, LineChartDirective, PieChartDirective, RangeChartDirective, TestChartDirective, TreemapChartDirective };
//# sourceMappingURL=oneteme-jquery-apexcharts.mjs.map
